# Command for building ioqoraudf library on unix platforms 

echo "Build Started"
echo ""
echo "Setting Environment Variables"	
date
echo ""

echo "Enter the platform"
read PLATFORM
if [ "$PLATFORM" == '' ]
then
   echo "No platform specified"
   exit 1 
fi

echo "Enter the path of ODPP bianries"
read SRC
if [ "$SRC" == '' ]
then
   echo "No path specified for ODPP binaries"
   exit 1 
fi

echo "Enter the path of Oracle include OCI.H"
read OCI_INC
if [ "$OCI_INC" == '' ]
then
   echo "No path specified for OCI.H"
   exit 1 
fi

echo "Enter compiler path, excluding compiler name"
read CMP_PATH
if [ "$CMP_PATH" == '' ]
then
   echo "No path specified for compiler"
   exit 1 
fi

echo "Source= "$SRC
echo "OCI Include= "$OCI_INC
echo "Platform= "$PLATFORM
echo "Compiler Path= "$CMP_PATH
echo ""

export COMMON_INC=-D_CPLUSPLUS 
export LIBPATH=.:$SRC:$OCI_INC

if test "$PLATFORM" = "RHEL32"
then
OUTPUT=$SRC/rhel32
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for RHEL 32bit"	
date
echo ""
echo ""
$CMP_PATH/g++ -m32 -Wall -fPIC -c $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -D_GNU_SOURCE -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o
$CMP_PATH/g++ -m32 -shared -Wl,-soname,libioqoraudf.so $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -o $OUTPUT/libioqoraudf.so -L$SRC -lODPPORAUdf 
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "RHEL64"
then
OUTPUT=$SRC/rhel64
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for RHEL 64bit"	
date
echo ""
echo ""
$CMP_PATH/g++ -m64 -Wall -fPIC -c $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -D_GNU_SOURCE -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o
$CMP_PATH/g++ -m64 -shared -Wl,-soname,libioqoraudf.so $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -o $OUTPUT/libioqoraudf.so -L$SRC -lODPPORAUdf 
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "SUSE32"
then
OUTPUT=$SRC/suse32
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for SUSE 32bit"	
date
echo ""
echo ""
$CMP_PATH/g++ -m32 -Wall -fPIC -c $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -D_GNU_SOURCE -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o
$CMP_PATH/g++ -m32 -shared -Wl,-soname,libioqoraudf.so $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -o $OUTPUT/libioqoraudf.so -L$SRC -lODPPORAUdf 
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "SUSE64"
then
OUTPUT=$SRC/suse64
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for SUSE 64bit"	
date
echo ""
echo ""
$CMP_PATH/g++ -m64 -Wall -fPIC -c $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -D_GNU_SOURCE -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o
$CMP_PATH/g++ -m64 -shared -Wl,-soname,libioqoraudf.so $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -o $OUTPUT/libioqoraudf.so -L$SRC -lODPPORAUdf 
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "AIX32"
then
OUTPUT=$SRC/aix32
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for AIX 32bit"	
date
echo ""
echo ""
$CMP_PATH/xlc++ -c -q32 $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o 
$CMP_PATH/xlc++ -qmkshrobj -q32 $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -o $OUTPUT/libioqoraudf.so -L$SRC -bdynamic -lODPPORAUdf -bnoipath -bE:$SRC/ioqoraudfunixexp.def
ar -rv $OUTPUT/libioqoraudf.a $OUTPUT/libioqoraudf.so
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "AIX64"
then
OUTPUT=$SRC/aix64
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for AIX 64bit"	
date
echo ""
echo ""
$CMP_PATH/xlc++ -c -q64 $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o 
$CMP_PATH/xlc++ -qmkshrobj -q64 $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -o $OUTPUT/libioqoraudf.so -L$SRC -bdynamic -lODPPORAUdf -bnoipath -bE:$SRC/ioqoraudfunixexp.def
ar -rv $OUTPUT/libioqoraudf.a $OUTPUT/libioqoraudf.so
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "HPUX32"
then
OUTPUT=$SRC/hpux32
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for HPUX 32bit"	
date
echo ""
echo ""
$CMP_PATH/aCC +DAportable  -c +z -AA -mt $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o
$CMP_PATH/aCC +DAportable  -b -Wl,+s,+cdp,$OUTPUT/: -AA -mt -Wl,+h,libioqoraudf.sl $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -L$SRC -lpthread -lODPPORAUdf -o $OUTPUT/libioqoraudf.sl
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "HPUX64"
then
OUTPUT=$SRC/hpux64
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for HPUX 64bit"	
date
echo ""
echo ""
$CMP_PATH/aCC +DAportable  -c +z -AA -mt +DD64 $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o
$CMP_PATH/aCC +DAportable  -b -Wl,+s,+cdp,$OUTPUT/: -AA +DD64 -mt -Wl,+h,libioqoraudf.sl $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -L$SRC -lpthread -lODPPORAUdf -o $OUTPUT/libioqoraudf.sl
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "HPIA32"
then
OUTPUT=$SRC/hpia32
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for HPIA 32bit"	
date
echo ""
echo ""
$CMP_PATH/aCC -c +z -AA +DD32 -mt $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o
$CMP_PATH/aCC -b -Wl,+s,+nodefaultrpath -AA +DD32 -mt -Wl,+h,libioqoraudf.so $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -L$SRC -lpthread -lODPPORAUdf -o $OUTPUT/libioqoraudf.so
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "HPIA64"
then
OUTPUT=$SRC/hpia64
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for HPIA 64bit"	
date
echo ""
echo ""
$CMP_PATH/aCC -c +z -AA +DD64 -mt $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o
$CMP_PATH/aCC -b -Wl,+s,+nodefaultrpath -AA +DD64 -mt -Wl,+h,libioqoraudf.so $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -L$SRC -lpthread -lODPPORAUdf -o $OUTPUT/libioqoraudf.so
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "SUN32"
then
OUTPUT=$SRC/sun32
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for SUN 32bit"	
date
echo ""
echo ""
$CMP_PATH/CC -xarch=v8plusa -xcode=pic32 -c $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o
$CMP_PATH/CC -xarch=v8plusa -xcode=pic32 -G -hlibioqoraudf.so $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -o $OUTPUT/libioqoraudf.so -L$SRC -lpthread -lODPPORAUdf
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "SUN64"
then
OUTPUT=$SRC/sun64
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for SUN 64bit"	
date
echo ""
echo ""
$CMP_PATH/CC -xarch=generic64 -xcode=pic32 -c $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o
$CMP_PATH/CC -xarch=generic64 -xcode=pic32 -G -hlibioqoraudf.so $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -o $OUTPUT/libioqoraudf.so -L$SRC -lpthread -lODPPORAUdf
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "ZRHL31"
then
OUTPUT=$SRC/zrhl31
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for ZRHL 32bit"	
date
echo ""
echo ""
$CMP_PATH/g++ -m31 -Wall -fPIC -c $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -D_GNU_SOURCE -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o
$CMP_PATH/g++ -m31 -shared -Wl,-soname,libioqoraudf.so $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -o $OUTPUT/libioqoraudf.so -L$SRC -lpthread -lODPPORAUdf
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "ZRHL64"
then
OUTPUT=$SRC/zrhl64
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for ZRHL 64bit"	
date
echo ""
echo ""
$CMP_PATH/g++ -m64 -Wall -fPIC -c $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -D_GNU_SOURCE -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o
$CMP_PATH/g++ -m64 -shared -export-dynamic -Wl,-soname,libioqoraudf.so $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -o $OUTPUT/libioqoraudf.so -L$SRC -lpthread -lODPPORAUdf
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "ZSUS31"
then
OUTPUT=$SRC/zsus31
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for ZSUS 32bit"	
date
echo ""
echo ""
$CMP_PATH/g++ -m31 -Wall -fPIC -c $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -D_GNU_SOURCE -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o
$CMP_PATH/g++ -m31 -shared -Wl,-soname,libioqoraudf.so $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -o $OUTPUT/libioqoraudf.so -L$SRC -lpthread -lODPPORAUdf
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "ZSUS64"
then
OUTPUT=$SRC/zsus64
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building Oracle UDF library for ZSUS 64bit"	
date
echo ""
echo ""
$CMP_PATH/g++ -m64 -Wall -fPIC -c $COMMON_INC $SRC/ioqoptimmaskorafunc.cpp -D_GNU_SOURCE -I$SRC -I$OCI_INC -o $OUTPUT/ioqoptimmaskorafunc.o
$CMP_PATH/g++ -m64 -shared -export-dynamic -Wl,-soname,libioqoraudf.so $SRC/ioqoracledata.o $OUTPUT/ioqoptimmaskorafunc.o -o $OUTPUT/libioqoraudf.so -L$SRC -lpthread -lODPPORAUdf
echo ""
echo "Build Completed"	
exit 0
fi
